@@ -51,9 +51,7 @@ impl BaseCounter{
     
     //----we had animate here but now nothing-!!!!!
 
-    pub fn get_attr_to_animate(&self)->AttributesEnum{
-        self.attr_to_animate
-    } 
+     
     
        
 }//end of impl block
@@ -90,5 +88,8 @@ impl Animatable for BaseCounter{
             None
         }
     }
+    fn get_attr_to_animate(&self)->AttributesEnum{
+        self.attr_to_animate
+    }
     
 }//impl Animatable for BaseCounter
